@@ -4,7 +4,7 @@
 
     gerbera.items.spec.js - this file is part of Gerbera.
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -335,7 +335,7 @@ describe('Gerbera Items', () => {
 
       Items.loadEditItem(editItemResponse);
 
-      expect(editObjectType.val()).toBe('item');
+      expect(editObjectType.val()).toBe('video');
       expect(editTitle.val()).toBe('Test.mp4');
       expect(editLocation.val()).toBe('/folder/location/Test.mp4');
       expect(editClass.val()).toBe('object.item.videoItem');
