@@ -3,7 +3,7 @@
 #
 # gerbera-shell.sh - this file is part of Gerbera.
 #
-# Copyright (C) 2024-2025 Gerbera Contributors
+# Copyright (C) 2024-2026 Gerbera Contributors
 #
 # Gerbera is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2
@@ -19,8 +19,33 @@
 #
 # $Id$
 
+lsb_codename=""
+lsb_distro=""
+lsb_rel=""
+lsb_arch="$(uname -p)"
+if [ -x "$(command -v dpkg)" ]; then
+    lsb_arch=$(dpkg --print-architecture)
+fi
 
-set -Eeuo pipefail
+if [ -x "$(command -v lsb_release)" ]; then
+    lsb_codename=$(lsb_release -c --short)
+    if [[ "${lsb_codename}" == "n/a" ]]; then
+        lsb_codename="unstable"
+    fi
+    lsb_distro=$(lsb_release -i --short)
+    lsb_rel=$(lsb_release -r --short)
+    lsb_codename=${lsb_codename,,}
+    lsb_distro=${lsb_distro,,}
+    lsb_rel=${lsb_rel,,}
+fi
+if [ -z "${lsb_codename}" ]; then
+    lsb_codename="$(uname -o)"
+    lsb_distro="$(uname)"
+    lsb_rel="unknown"
+    lsb_codename=${lsb_codename,,}
+    lsb_distro=${lsb_distro,,}
+    lsb_rel=${lsb_rel,,}
+fi
 
 if [[ -z "${ROOT_DIR-}" ]]; then
   GRB_SH_DIR=$(dirname "$0")
@@ -29,6 +54,8 @@ else
   GRB_SH_DIR="${ROOT_DIR}scripts/"
 fi
 
+set -Eeuo pipefail
+
 function install-fmt() {
   echo "::group::Installing fmt"
   sudo bash "${GRB_SH_DIR}install-fmt.sh" static
@@ -41,6 +68,19 @@ function install-spdlog() {
   echo "::endgroup::"
 }
 
+function install-libpqxx() {
+  echo "::group::Installing libpqxx"
+  sudo bash "${GRB_SH_DIR}install-libpqxx.sh" $*
+  echo "::endgroup::"
+}
+
+function install-libzippp() {
+  echo "::group::Installing libzippp"
+  sudo bash "${GRB_SH_DIR}install-libzip.sh" $*
+  sudo bash "${GRB_SH_DIR}install-libzippp.sh" $*
+  echo "::endgroup::"
+}
+
 function install-pupnp() {
   echo "::group::Installing libupnp"
   sudo bash "${GRB_SH_DIR}install-pupnp.sh"
@@ -101,3 +141,15 @@ function install-ffmpegthumbnailer() {
   sudo bash "${GRB_SH_DIR}install-ffmpegthumbnailer.sh"
   echo "::endgroup::"
 }
+
+function install-wavpack() {
+  echo "::group::Installing WavPACK"
+  sudo bash "${GRB_SH_DIR}install-wavpack.sh"
+  echo "::endgroup::"
+}
+
+function install-jsoncpp() {
+  echo "::group::Installing JsonCPP"
+  sudo bash "${GRB_SH_DIR}install-jsoncpp.sh"
+  echo "::endgroup::"
+}
