@@ -3,7 +3,7 @@
 
     test_tools.cc - this file is part of Gerbera.
 
-    Copyright (C) 2016-2025 Gerbera Contributors
+    Copyright (C) 2016-2026 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -20,12 +20,15 @@
     $Id$
 */
 
+#include "cds/cds_resource.h"
 #include "util/grb_fs.h"
 #include "util/grb_net.h"
 #include "util/grb_time.h"
 #include "util/tools.h"
 #include "util/url_utils.h"
 
+#include <fmt/chrono.h>
+#include <fmt/core.h>
 #include <gtest/gtest.h>
 
 TEST(ToolsTest, simpleDate)
@@ -46,6 +49,33 @@ TEST(ToolsTest, simpleDate)
     EXPECT_EQ(makeSimpleDate(dt), "2009-08-21T14:31:41Z");
 }
 
+TEST(ToolsTest, parseDate)
+{
+    {
+        auto dt = "20240321";
+        std::tm tmWork {};
+        EXPECT_TRUE(parseDate(dt, tmWork));
+        EXPECT_EQ(fmt::format("{:%Y-%m-%d}", tmWork), "2024-03-21");
+    }
+    {
+        auto dt = "2024-03-21";
+        std::tm tmWork {};
+        EXPECT_TRUE(parseDate(dt, tmWork));
+        EXPECT_EQ(fmt::format("{:%Y-%m-%d}", tmWork), "2024-03-21");
+    }
+    {
+        auto dt = "2024";
+        std::tm tmWork {};
+        EXPECT_TRUE(parseDate(dt, tmWork));
+#ifdef SOLARIS
+        // don't know what's broken here
+        EXPECT_EQ(fmt::format("{:%Y-%m-%d}", tmWork), "2023-12-31");
+#else
+        EXPECT_EQ(fmt::format("{:%Y-%m-%d}", tmWork), "2024-01-01");
+#endif
+    }
+}
+
 TEST(ToolsTest, millisecondsToHMSF)
 {
     EXPECT_EQ(millisecondsToHMSF(0), "0:00:00.000");
@@ -142,23 +172,23 @@ TEST(ToolsTest, splitStringTest)
     auto parts = splitString("", ',');
     EXPECT_EQ(parts.size(), 0);
 
-    parts = splitString("", ',', true);
+    parts = splitString("", ',', '\0', true);
     EXPECT_EQ(parts.size(), 1);
 
     parts = splitString("A", ',');
     ASSERT_EQ(parts.size(), 1);
     EXPECT_EQ(parts[0], "A");
 
-    parts = splitString("A,", ',', false);
+    parts = splitString("A,", ',', '\0', false);
     ASSERT_EQ(parts.size(), 1);
     EXPECT_EQ(parts[0], "A");
 
-    parts = splitString("A,", ',', true);
+    parts = splitString("A,", ',', '\0', true);
     ASSERT_EQ(parts.size(), 2);
     EXPECT_EQ(parts[0], "A");
     EXPECT_EQ(parts[1], "");
 
-    parts = splitString(",A", ',', true);
+    parts = splitString(",A", ',', '\0', true);
     ASSERT_EQ(parts.size(), 2);
     EXPECT_EQ(parts[0], "");
     EXPECT_EQ(parts[1], "A");
@@ -169,12 +199,12 @@ TEST(ToolsTest, splitStringTest)
     EXPECT_EQ(parts[1], "B");
     EXPECT_EQ(parts[2], "C");
 
-    parts = splitString("A,,C", ',', false);
+    parts = splitString("A,,C", ',', '\0', false);
     ASSERT_EQ(parts.size(), 2);
     EXPECT_EQ(parts[0], "A");
     EXPECT_EQ(parts[1], "C");
 
-    parts = splitString("A,,C", ',', true);
+    parts = splitString("A,,C", ',', '\0', true);
     ASSERT_EQ(parts.size(), 3);
     EXPECT_EQ(parts[0], "A");
     EXPECT_EQ(parts[1], "");
@@ -184,17 +214,51 @@ TEST(ToolsTest, splitStringTest)
     auto resourceString = "0~protocolInfo=http-get%3A%2A%3Aimage%2Fjpeg%3A%2A&resolution=3327x2039&size=732150~~|1~protocolInfo=http-get%3A%2A%3Aimage%2Fjpeg%3A%2A&resolution=170x256~rct=EX_TH~";
     auto resourceParts = splitString(resourceString, '|');
     ASSERT_EQ(resourceParts.size(), 2);
-    auto parts0 = splitString(resourceParts[0], '~', true);
-    auto parts1 = splitString(resourceParts[1], '~', true);
+    auto parts0 = splitString(resourceParts[0], '~', '\0', true);
+    auto parts1 = splitString(resourceParts[1], '~', '\0', true);
     ASSERT_EQ(parts0.size(), 4);
     ASSERT_EQ(parts1.size(), 4);
+
+    // Test splitString on usecase where 'empty' and 'quote' is in use
+    auto commandString = R"(-I dummy %in --sout "#transcode{ venc=ffmpeg, vcodec=mp2v, vb=4096, fps=25, aenc=ffmpeg, acodec=mpga, ab=192, samplerate=44100, channels=2 }:standard{ access=file, mux=ps, dst=%out }" vlc:quit)";
+    auto commandParts = splitString(commandString, ' ', '"');
+    ASSERT_EQ(commandParts.size(), 6);
+    auto cmd0 = splitString(commandParts[4], ':', '\0', true);
+    ASSERT_EQ(cmd0.size(), 2);
+    auto cmd1 = splitString(cmd0[1], ' ', '\0', true);
+    EXPECT_EQ(cmd1.size(), 5);
+    EXPECT_EQ(cmd1[0], "standard{");
+}
+
+TEST(ToolsTest, populateCommandLineTest)
+{
+    {
+        auto commandString = R"(-I dummy %in --sout "#transcode{ venc=ffmpeg, vcodec=mp2v, vb=4096, fps=25, aenc=ffmpeg, acodec=mpga, ab=192, samplerate=44100, channels=2 }:standard{ access=file, mux=ps, dst=%out }" vlc:quit)";
+        auto commandParts = populateCommandLine(commandString, "IN", "OUT", "RANGE", "TITLE");
+        ASSERT_EQ(commandParts.size(), 6);
+        EXPECT_EQ(commandParts[2], "IN");
+        auto cmd0 = splitString(commandParts[4], ':', '\0', true);
+        ASSERT_EQ(cmd0.size(), 2);
+        auto cmd1 = splitString(cmd0[1], ' ', '\0', true);
+        ASSERT_EQ(cmd1.size(), 5);
+        EXPECT_EQ(cmd1[3], "dst=OUT");
+    }
+    {
+        auto commandString = R"(-I dummy %in --sout=%out --range %range --title %title)";
+        auto commandParts = populateCommandLine(commandString, "IN", "OUT", "RANGE", "TITLE");
+        ASSERT_EQ(commandParts.size(), 8);
+        EXPECT_EQ(commandParts[2], "IN");
+        EXPECT_EQ(commandParts[3], "--sout=OUT");
+        EXPECT_EQ(commandParts[7], "TITLE");
+    }
 }
 
 TEST(ToolsTest, replaceAllStringTest)
 {
     std::string str = "test ( with br";
     replaceAllString(str, "(", "\\\(");
-    EXPECT_EQ(str, "test \\" "( with br");
+    EXPECT_EQ(str, "test \\"
+                   "( with br");
 
     str = "test ] with br";
     replaceAllString(str, "]", "\\]");
@@ -231,6 +295,8 @@ TEST(ToolsTest, expandNumbersStringTest)
     EXPECT_EQ(expandNumbersString("A0001b00002c", 3), "A0001b00002c");
     EXPECT_EQ(expandNumbersString("A1b2", 3), "A001b002");
     EXPECT_EQ(expandNumbersString("1b2c", 3), "001b002c");
+    EXPECT_EQ(expandNumbersString("9999999999", 15), "000009999999999");
+    EXPECT_EQ(expandNumbersString("9999999999999999999999", 15), "9999999999999999999999");
 }
 
 TEST(ToolsTest, startswithTest)
@@ -314,6 +380,23 @@ TEST(ToolsTest, pathToMapTest)
     EXPECT_EQ(values[""], "meh");
 }
 
+TEST(ToolsTest, formatSizeTest)
+{
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("512")), "512 B");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("1024")), "1.00 kB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("1048576")), "1.00 MB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("8388608")), "8.00 MB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("1073741824")), "1.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("2147483648")), "2.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("4294967296")), "4.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("8589934592")), "8.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(stoumaxString("1099511627776")), "1.00 TB");
+    EXPECT_EQ(CdsResource::formatSizeValue(1073741824), "1.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(8589934592), "8.00 GB");
+    EXPECT_EQ(CdsResource::formatSizeValue(1099511627776), "1.00 TB");
+    EXPECT_EQ(CdsResource::formatSizeValue(1125899906842624LL), "1024.00 TB");
+}
+
 TEST(ToolsTest, parseTimeTest)
 {
     std::string value = "01:01:01:01";
